/*
 * $Id: kblock.h 870 2007-12-14 06:45:43Z hubert@u.washington.edu $
 *
 * ========================================================================
 * Copyright 2006 University of Washington
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * ========================================================================
 */

#ifndef PINE_KBLOCK_INCLUDED
#define PINE_KBLOCK_INCLUDED


#ifdef KEYBOARD_LOCK

/* exported protoypes */
int	    lock_keyboard(void);

#endif	/* KEYBOARD_LOCK */

#endif /* PINE_KBLOCK_INCLUDED */
